summaryrefslogtreecommitdiffstats
path: root/win/CS/HandBrakeWPF/Properties/Resources.Designer.cs
diff options
context:
space:
mode:
Diffstat (limited to 'win/CS/HandBrakeWPF/Properties/Resources.Designer.cs')
-rw-r--r--win/CS/HandBrakeWPF/Properties/Resources.Designer.cs17
1 files changed, 13 insertions, 4 deletions
diff --git a/win/CS/HandBrakeWPF/Properties/Resources.Designer.cs b/win/CS/HandBrakeWPF/Properties/Resources.Designer.cs
index b749f54e4..e278190f5 100644
--- a/win/CS/HandBrakeWPF/Properties/Resources.Designer.cs
+++ b/win/CS/HandBrakeWPF/Properties/Resources.Designer.cs
@@ -2110,7 +2110,7 @@ namespace HandBrakeWPF.Properties {
}
/// <summary>
/// Looks up a localized string similar to Preset:.
/// </summary>
public static string MainView_Presets {
get {
@@ -2218,11 +2218,11 @@ namespace HandBrakeWPF.Properties {
}
/// <summary>
- /// Looks up a localized string similar to Selected Preset:.
+ /// Looks up a localized string similar to Preset:.
/// </summary>
- public static string MainView_SelectedPreset {
+ public static string MainView_SelectedPresets {
get {
- return ResourceManager.GetString("MainView_SelectedPreset", resourceCulture);
+ return ResourceManager.GetString("MainView_SelectedPresets", resourceCulture);
}
}
@@ -5615,6 +5615,15 @@ namespace HandBrakeWPF.Properties {
}
/// <summary>
+ /// Looks up a localized string similar to Same as source.
+ /// </summary>
+ public static string SummaryView_SameAsSource {
+ get {
+ return ResourceManager.GetString("SummaryView_SameAsSource", resourceCulture);
+ }
+ }
+
+ /// <summary>
/// Looks up a localized string similar to storage.
/// </summary>
public static string SummaryView_storage {
@@ -2110,7 +2110,7 @@ namespace HandBrakeWPF.Properties {
}
/// <summary>
- /// Looks up a localized string similar to Preset:.
+ /// Looks up a localized string similar to Presets.
/// </summary>
public static string MainView_Presets {